@@ -6,18 +6,18 @@
 #ifndef IBASELOADER_H
 #define IBASELOADER_H
 
-#include <wx/string.h>
 #include "settings.h"
-#include "tinyxml/tinyxml.h"
+
+class wxString;
 
 /** Base interface for project loaders. */
 class DLLIMPORT IBaseLoader
 {
-	public:
+    public:
         /// Constructor
-		IBaseLoader(){}
-		/// Destructor
-		virtual ~IBaseLoader(){}
+        IBaseLoader(){}
+        /// Destructor
+        virtual ~IBaseLoader(){}
 
         /** Open a file.
           * @param filename The file to open.
@@ -28,7 +28,6 @@ class DLLIMPORT IBaseLoader
           * @param filename The file to save.
           * @return True on success, false on failure. */
         virtual bool Save(const wxString& filename) = 0;
-    protected:
 };
 
 #endif // IBASELOADER_H
